@@ -11,9 +11,11 @@ from jinja2 import Environment, FileSystemLoader
 class NxPyDocs():
     def __init__(self,
                 command,
-                filetype):
+                filetype,
+                repo):
         self.command = command
         self.filetype = filetype
+        self.repo = repo
         self.supported_templates = [
                             # 'show access-lists',
                             # 'show bgp process vrf all',
@@ -46,20 +48,24 @@ class NxPyDocs():
                 self.command = single_command
                 command_output = clid( '%s' % self.command )
                 parsed_json = json.loads(command_output)
-                if "Cannot" in parsed_json:
-                    click.secho("No Data To Create File", fg='red')
-                else:
-                    if self.filetype:
-                        self.pick_filetype(parsed_json)
+                if self.repo:
+                    self.clone()
+                if self.filetype:
+                    self.pick_filetype(parsed_json)
+                    if self.repo:
+                        self.send_to_repo()
         else:
             if self.command in self.supported_templates:
                 command_output = clid( '%s' % self.command )
                 parsed_json = json.loads(command_output)
-                if "Cannot" in parsed_json:
-                    click.secho("No Data To Create File", fg='red')
+                if self.repo:
+                    self.clone()                
+                if self.filetype:
+                    self.pick_filetype(parsed_json)
+                    if self.repo:
+                        self.send_to_repo()
                 else:
-                    if self.filetype:
-                        self.pick_filetype(parsed_json)
+                    click.secho(json.dumps(parsed_json,indent=4, sort_keys=True))
             else:
                 click.secho("Show Command Not Yet Templated", fg='red')
 
@@ -76,15 +82,15 @@ class NxPyDocs():
             self.markdown_file(parsed_json)
         elif self.filetype == 'csv':
             self.csv_file(parsed_json)
-        elif self.filetype == 'mindmap':            
-            self.mindmap_file(parsed_json)           
+        elif self.filetype == 'mindmap':
+            self.mindmap_file(parsed_json)
         elif self.filetype == 'all':
             self.all_files(parsed_json)
 
     def json_file(self, parsed_json):
         with open(' %s.json' % self.command, 'w') as f:
             f.write(json.dumps(parsed_json,indent=4, sort_keys=True))
-        print(json.dumps(parsed_json,indent=4, sort_keys=True))            
+        click.secho(json.dumps(parsed_json,indent=4, sort_keys=True))
         click.secho("JSON file created at %s / %s.json" % (sys.path[0],self.command),
         fg='green')
 
@@ -93,7 +99,7 @@ class NxPyDocs():
         clean_yaml = dirty_yaml.replace("!!python/unicode","")
         with open(' %s.yaml' % self.command, 'w') as f:
             f.write(clean_yaml)
-        print(clean_yaml)
+        click.secho(clean_yaml)
         click.secho("YAML file created at %s / %s.yaml" % (sys.path[0],self.command),
         fg='green')
 
@@ -105,7 +111,7 @@ class NxPyDocs():
             data_to_template=parsed_json)
         with open('%s.html' % self.command, 'w') as f:
             f.write(html_output)
-        print(html_output)
+        click.secho(json.dumps(parsed_json,indent=4, sort_keys=True))
         click.secho("HTML file created at %s / %s.html" % (sys.path[0],self.command),
             fg='green')
 
@@ -117,7 +123,7 @@ class NxPyDocs():
             data_to_template=parsed_json)
         with open('%s.md' % self.command, 'w') as f:
             f.write(markdown_output)
-        print(markdown_output)
+        click.secho(json.dumps(parsed_json,indent=4, sort_keys=True))
         click.secho("Markdown file created at %s / %s.md" % (sys.path[0],self.command),
             fg='green')
 
@@ -130,7 +136,7 @@ class NxPyDocs():
             )
         with open('%s.csv' % self.command, 'w') as f:
             f.write(csv_output)
-        print(csv_output)
+        click.secho(json.dumps(parsed_json,indent=4, sort_keys=True))
         click.secho("CSV file created at %s / %s.csv" % (sys.path[0],self.command),
             fg='green')
 
@@ -143,9 +149,8 @@ class NxPyDocs():
             )
         with open('%s mindmap.md' % self.command, 'w') as f:
             f.write(mindmap_output)
-        print(mindmap_output)
-        click.secho(
-            "Mindmap file created at %s / %s.md" % (sys.path[0],self.command),
+        click.secho(json.dumps(parsed_json,indent=4, sort_keys=True))
+        click.secho("Mindmap file created at %s / %s.md" % (sys.path[0],self.command),
             fg='green')
 
     def all_files(self, parsed_json):
@@ -156,6 +161,14 @@ class NxPyDocs():
         self.csv_file(parsed_json)
         self.mindmap_file(parsed_json)
 
+    def clone(self):
+        os.system("git clone %s ." % self.repo)
+
+    def send_to_repo(self):       
+        os.system("git add *")
+        os.system("git commit -am 'nxpydocs generated this commit")
+        os.system("git push")
+
 @click.command()
 @click.option('--command',
     prompt='Command',
@@ -175,11 +188,17 @@ class NxPyDocs():
     help='Filetype to output captured network state to',
     required=False,
     default='none')
+@click.option('--repo',
+    prompt='Git Repository',
+    help=('The Git repository to send the output files'),
+    required=False)
 def cli(command,
         filetype,
+        repo,
         ):
     invoke_class = NxPyDocs(command,
                             filetype,
+                            repo
                         )
     invoke_class.nxpydocs()
 
